@@ -3,7 +3,7 @@ use warnings;
 package Software::Security::Policy;
 # ABSTRACT: packages that provide templated Security Policys
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use Data::Section -setup => { header_re => qr/\A__([^_]+)__\Z/ };
 use Text::Template ();
@@ -27,7 +27,7 @@ sub git_url { (defined $_[0]->{git_url} ? $_[0]->{git_url} :
                 'SECURITY.md')) }
 
 
-sub support_years { $_[0]->{support_years} || '10'}
+sub perl_support_years { (defined $_[0]->{perl_support_years} ? $_[0]->{perl_support_years} : '10') };
 
 sub timeframe {
     return $_[0]->{timeframe} if defined $_[0]->{timeframe};
@@ -100,7 +100,7 @@ Software::Security::Policy - packages that provide templated Security Policys
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ version 0.04
     program     => 'Software::Security::Policy',
     timeframe   => '7 days',
     url         => 'https://github.com/CPAN-Security/Software-Security-Policy/blob/main/SECURITY.md',
-    support_years   => '10',
+    perl_support_years   => '10',
   });
 
   print $policy->fulltext, "\n";
@@ -165,7 +165,7 @@ a url where the most current security policy can be found.
 
 a git url where the most current security policy can be found.
 
-=item support_years
+=item perl_support_years
 
 the number of years for which past major versions of Perl would be
 supported
@@ -184,9 +184,10 @@ capitalized "this program", if both arguments are omitted.
 
 =back
 
-=head2 support_years
+=head2 perl_support_years
 
-Get the number of years of support to be expected
+Get the number of years for which past major versions of Perl would be
+supported.
 
 =head2 timeframe
 
