@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::Security::Policy::Individual;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use parent 'Software::Security::Policy';
 # ABSTRACT: The Individual Security Policy
@@ -22,7 +22,7 @@ Software::Security::Policy::Individual - The Individual Security Policy
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
@@ -122,7 +122,7 @@ The maintainer(s) will only commit to releasing security fixes for
 the latest version of {{ $self->program }}.
 
 Note that the {{ $self->program }} project only supports major versions of Perl
-released in the past {{ $self->support_years }} years, even though {{ $self->program }} will run on
+released in the past {{ $self->perl_support_years }} years, even though {{ $self->program }} will run on
 older versions of Perl.  If a security fix requires us to increase
 the minimum version of Perl that is supported, then we may do so.
 
